# An artificial example trying to show that sometimes it may be easy
# to write the parametric function as a Python implementation, but
# giving it as a pair of functions (x(t),y(t)) would be much harder
# or even impossible.

def astroid_play(t):
    R = 0.75                   # Choose a number between 0.5 and 1
    x,y = cos(t)**3, sin(t)**3 # Astroid
    r = sqrt(x**2 + y**2)      # Radius
    r1 = R + abs(r-R)          # Reflect points with r<R in circle r=R
    r1 = r1**2                 # To get stronger effect
    return [(r1/r)*x, (r1/r)*y]

pcurve = ParametricCurve(
    function = astroid_play,
    pcurve_name = "astroid play",
    start  = 0.,
    end    = 2*pi,
    closed = True,
    custom = CustomPoints(params = [pi/2, pi, 3*pi/2])
    )

pcurve_collage = ParametricCurveCollage(
    pcurve_list  = [pcurve],
    collage_name = 'Astroid play'
    )

# Using default values for c2bs, c2b0, coos, drawo, mark_polylines:
# they can be omitted
