# This file creates a demonstration of approximations of y=cos(x) by
# some Taylor polynomials (with everything drawn as approximations
# by Bezier curves!). A little slow.
# This picture could appear in mathematics lecture notes.

from functools import partial

def cos_function(t):
    from math import cos
    return [t, cos(t)]

def poly_general(t,n): # Taylor of degree 2*n
    t = float(t)
    p = 1.
    term = 1.
    for i in range(1,n+1):
        term *= t/i
        if i%2 != 0:
            continue
        if i%4 == 0:
            p += term
        else:
            p -= term
    return [t,p]

cosine = ParametricCurve(
    function = cos_function,
    pcurve_name   = "cos",
    start  = -6*pi,
    end    = 6*pi,
    closed = False,
    )

N=17 # Number of Taylor approximations we calculate.

taylor0 = ParametricCurve( # Taylor of degree 0.
    function = partial(poly_general, n=0),
    pcurve_name   = "Taylor of degree 0",
    start  = -6*pi,
    end    = 6*pi,
    closed = False,
    )

def interval(i): # Quite ad hoc to get a nice picture.
    x = pi*(i/4)+pi*25/(i+24)
    if i == 1: return x+pi/4
    elif i == 2: return x+pi/16
    else: return x

taylor_polynomials = [ParametricCurve( # Higher Taylor polynomials.
    function = partial(poly_general, n=2*i),
    pcurve_name   = "Taylor of degree "+str(2*i),
    start  = -interval(i),
    end    =  interval(i),
    closed = False,
    ) for i in range(1,N)]

pcurve_collage = ParametricCurveCollage(
    pcurve_list = [taylor0] + taylor_polynomials + [cosine],
    collage_name = 'cos(x) and Taylor approximations'
    )

c2bs = Curve2BezierSettings()

c2bo = Curve2BezierOptions()

coos = CoordinateSettings()

drawo = DrawingOptions(
    axes=True
    )

