# The cycloid.
# Note how the custom points are used to tell the program the two cusp points.
# If the 'custom' field is omitted, the program should nevertheless find
# the cusp points, but they may become a little inexact.

def cycloid(t):
    from math import cos,sin
    return [t-sin(t), 1-cos(t)]

pcurve = ParametricCurve(                # Cycloid
    function = cycloid,
    pcurve_name   = "cycloid",
    start  = -0.5*pi,
    end    = 2.5*pi,
    closed = False,
    custom = CustomPoints(params = [ 0., 2*pi ])
    )

pcurve_collage = ParametricCurveCollage(
    pcurve_list = [pcurve],
    collage_name        = 'Cycloid'
    )

c2bs = Curve2BezierSettings(
    refinement = 1,     # For better approximation.
    )

c2bo = Curve2BezierOptions()

coos = CoordinateSettings(
    fit_window = True,
    )

drawo = DrawingOptions(
    axes = False,
    x_axis = True,
    exact_pcurves = True, # To compare the result with the exact cycloid.
    handles = True        # To see the resulting control points.
    )

