# The golden spiral.
# The subdivision is constructed using only angle_turn_points
# (there are no cusps etc).
# Below in 'c2bs' the angle is set to pi/4.
# Try drawing also with that line commented out.
# Then the default angle=pi/2 is used. Zoom in and compare.
# The first curve has more control points and is slightly more accurate.
# You can check the accuracy visually by uncommenting in 'drawo' the line
#
#    #exact_pcurves = True # Uncomment to check the result visually.
#
# Then points on the exact spiral are marked with small stars.
# 

def golden_spiral(t):
    from math import sin,cos,exp
    b = 0.30634896253003313 # (2/pi)*log((1+sqrt(5))/2)
    r = exp(-b*t)
    return [r*cos(t), r*sin(t)]

pcurve = ParametricCurve(                # Golden spiral
    function = golden_spiral,
    pcurve_name = "golden spiral",
    start  = 0.,
    end    = 4*pi,
    closed = False,
    custom = None
    )

c2bs = Curve2BezierSettings(
    angle = pi/4, # Default = pi/2. Try also with this line commented out.
    )

c2bo = Curve2BezierOptions(
    cusp_points           = False,
    high_curvature_points = False,
    low_curvature_points  = False,
    straight_end_points   = False,
    inflection_points     = False,
    angle_turn_points     = True # This is the only needed for the spiral
    )

coos = CoordinateSettings()      # default

drawo = DrawingOptions(
    bezier_curves = True,
    axes   = False,
    x_axis = True,
    y_axis = True,
    #exact_pcurves = True # Uncomment to check the result visually.
    )

pcurve_collage = ParametricCurveCollage(
    pcurve_list = [pcurve],
    collage_name = 'Example: golden spiral'
    )

