# The lemniscate.
# We use a parametric representation which gives the whole curve.
#
# Note: Some custom points are added (they will be anchors) just for the
# sake of demonstration:
# - the self-intersection point t=pi/2, t=3*pi/2 (these make no difference!);
# - [+-.25, +-.25] using CustomPoints(points=...). These points are not
# (and need not be) exactly on the true lemniscate - the plugin finds the
# closest points on the curve to be used as anchors (these improve accuracy
# very slightly).

def lemniscate(t):
    s = sin(t)
    x = cos(t) / (1+ s**2)
    return [x, x*s]

pcurve = ParametricCurve(
    function = lemniscate,
    pcurve_name = "lemniscate",
    start  = 0.,
    end    = 2*pi,
    closed = True,
    custom = CustomPoints(params = [pi/2, 3*pi/2],
                          points = [[.25,-.25], [.25, .25], [-.25,-.25], [-.25, .25]]
                          )
    )

pcurve_collage = ParametricCurveCollage(
    pcurve_list  = [pcurve],
    collage_name = 'Lemniscate'
    )

c2bs = Curve2BezierSettings()    # default
c2bo = Curve2BezierOptions()    # default

coos = CoordinateSettings(
    fit_window = True,
    padding     = 0.15,
    )

drawo = DrawingOptions(
    exact_pcurves  = True,  # To compare with the correct curve.
    handles        = True   # To see the handles
    )



