# The lemniscate.
# We use a parametric representation which gives only one half
# of the curve at a time.
# So, we define a parametric curve for each half separately
# (same function but with different intervals for the parameter),
# and then we build a 'pcurve_collage' from the two halves.
#
def lemniscate(t):
    c = cos(2*t)
    try:
        s = sqrt(c)
        return [s*cos(t), s*sin(t)]
    except:
        return [0.,0.]

pcurve0 = ParametricCurve(       # Lemniscate right loop
    function = lemniscate,
    pcurve_name = "lemniscate arc 1",
    start  = -pi/4,
    end    = pi/4,
    closed = True,
    )

pcurve1 = ParametricCurve(       # Lemniscate left loop
    function = lemniscate,
    pcurve_name = "lemniscate arc 2",
    start  = 3*pi/4,
    end    = 5*pi/4,
    closed = True,
    )

pcurve_collage = ParametricCurveCollage(
    pcurve_list = [pcurve0, pcurve1],
    collage_name = 'Lemniscate two arcs'
    )

c2bs = Curve2BezierSettings()

c2bo = Curve2BezierOptions()

coos = CoordinateSettings(
    fit_window = True,
    padding    = 0.15,
    )

drawo = DrawingOptions(
    bezier_curves  = False, # Do not draw the two halves separately;
    bezier_collage = True,  # instead draw the merged-down vectors object.
    exact_pcurves  = True,  # To compare with the correct curve.
    handles = True          # To see the handles
    )

