# Drawing a near circle with only two anchors.
# We do this by trying to approximate a circle, but we force the program
# to use 180 degree arcs (instead of the default 90 degrees), and
# we prohibit any recursion, and we force it to allow larger
# errors than default.
#
# In this example, for demonstrations sake, the exact circle is
# shown by small stars along the circle, and the anchors and handles
# of the computed Bezier curve are shown as a separate path.

def circle(t):
    from math import cos,sin
    return [cos(t), sin(t)]

pcurve = ParametricCurve(                # Circle
    function = circle,
    pcurve_name = "circle",
    start  = 0.,
    end    = 2*pi,
    closed = True,
    )

pcurve_collage = ParametricCurveCollage(
    pcurve_list = [pcurve],
    collage_name = 'near circle'
    )

c2bs = Curve2BezierSettings(
    angle         = pi, # The default value would be pi/2.
    max_recursion = 0,  # To prohibit any refinement by recursion.
    )

c2bo = Curve2BezierOptions(
    )

coos = CoordinateSettings(
    fit_window = True,
    )

drawo = DrawingOptions(
    bezier_curves  = False,
    bezier_collage = True,
    exact_pcurves  = True, # Show the exact circle
    handles        = True, # Show the anchors and handles.
    )

