# The normal distribution, mean=0, variance=0.1.
# An example of drawing a function y=f(x).
# To check the result, the correct curve is shown with small stars.

from functools import partial

def normal_distribution_general(t,mean,variance):
    coefficient = 0.3989422804014327 # 1/sqrt(2*pi)
    c = coefficient/sqrt(variance)
    exponent = -((t-mean)**2)/(2*variance)
    return [t, c*exp(exponent)]

normal = partial(normal_distribution_general, mean=0,variance=.1)

pcurve = ParametricCurve(
    function = normal,
    pcurve_name = "normal distribution",
    start  = -1.,
    end    = 1.,
    closed = False,
    custom = None
    )

c2bs = Curve2BezierSettings()    # default

c2bo = Curve2BezierOptions(
    cusp_points           = False,
    high_curvature_points = True,
    low_curvature_points  = True,
    straight_end_points   = False,
    inflection_points     = False,
    angle_turn_points     = True
    )

coos = CoordinateSettings()      # default

drawo = DrawingOptions(
    bezier_curves = True,
    exact_pcurves = True, # Show the exact curve
    axes   = False,
    x_axis = True,
    y_axis = True,
    )

pcurve_collage = ParametricCurveCollage(
    pcurve_list = [pcurve],
    collage_name = 'Normal distribution'
    )

