# Rhodonea
# https://en.wikipedia.org/wiki/Rose_(mathematics)
#
# Formula in polar coordinates (r,t):
#
#     r = scale * [cos(kt) + offset]
#
# where k = a/b with a,b integers. (This gives a closed curve, which is what is
# implemented here. You may wish to make your own implementation with k irrational.)
#
# Changing a and b you get very different shapes, and offset has a striking
# effect too. See the Wikipedia page for examples.
#
############# Parameters: edit to get different curves ############################
a,b = 5,6      # 
#a,b = 4,5     # Try these too,
#a,b = 1,5     # or these,
#a,b = 2,5     # or these, or whatever.
#
offset = 0.    # Default offset.
#offset = 0.75 # Try this offset too,
#offset = 1.15 # or this, or even larger.
#
scale = 1.     # Scaling factor.
rotate = 0.    # Rotation in degrees
###################################################################################


# Greatest common divisor.
def gcd(m,n):
    if m==0 and n==0:
        return None
    x,y = abs(m),abs(n)
    if x<y: x,y = y,x
    while y != 0:
        x,y = y, x%y
    return x

# Input a,b: Integers
# Find a/b = x/y where gcd(x,y)=1 and y>=0.
# Return None if a=b=0.
def reduce_fraction(a,b):
    if a==0 and b==0: return None
    if b == 0:        return 1,0
    if a == 0:        return 0,1
    if b<0:           a,b = -a,-b
    d = gcd(a,b)
    return a//d, b//d

def make_rhodonea_function(
    a=5,       # integer
    b=6,       # integer
    offset=0., # float
    scale=1.,  # float
    rotate=0.  # float
    ):
    from math import pi, cos, sin
    if a == 0: a = 1
    if b == 0: b = 1
    N,n = reduce_fraction(a,b)
    k = float(N)/float(n)
    K = 1./k
    c,s = cos(rotate*pi/180), sin(rotate*pi/180)
    def rhodonea_function(t):
        from math import cos,sin
        r = scale * (cos(k*t) + offset)
        x = r * cos(t)
        y = r * sin(t)
        x, y = c*x - s*y, s*x + c*y # rotation
        return [scale*x, scale*y]
    interval = [0., 2*n*pi]                 # Start, end for one closed period.
    maxima = [2*i*K*pi for i in range(1,N)] # Excludes start, end.
    minima = [(2*i+1)*K*pi for i in range(N)]
    return rhodonea_function, interval, maxima, minima


rhodonea, interval, mx, mn = make_rhodonea_function(a, b, offset, scale, rotate)

pcurve = ParametricCurve(
    function    = rhodonea,
    pcurve_name = ("rhodonea "+str(a)+", "+str(b)+", "+str(offset)
                   +", "+str(scale)+", "+str(rotate)),
    start       = interval[0],
    end         = interval[1],
    closed      = True,
    custom      = CustomPoints(params = mx + mn)
    )

pcurve_collage = ParametricCurveCollage(
    pcurve_list  = [pcurve], # 
    collage_name = 'Rhodonea'
    )

# Default values:
#c2bs = Curve2BezierSettings()
#
#c2bo = Curve2BezierOptions()
#
#coos = CoordinateSettings()
#
#drawo = DrawingOptions()

