# Drawing the function y=sin(x) with a small number of control points.
# We trick the plugin to put anchors only at the extremum points.
# To demonstrate the accuracy of the result, the exact sine function
# is also drawn (as small stars), and in addition the anchors and handles
# of the computed Bezier curve are drawn.

def sine_function(t):
    from math import cos,sin
    return [t,sin(t)]

pcurve = ParametricCurve(                # sin(x)
    function = sine_function,
    pcurve_name = "sine",
    start  = -pi,
    end    = 3*pi,
    closed = False,
    )

pcurve_collage = ParametricCurveCollage(
    pcurve_list = [pcurve],
    collage_name = 'sine'
    )

c2bs = Curve2BezierSettings()

# We suppress searching for inflection points by setting
#    low_curvature_points  = False
#    inflection_points     = False
# Then we must also set
#    angle_turn_points     = False
# since otherwise the plugin would force inflection_points to True.
# The reason for this behaviour is that the algorithm which searches for
# the points where the arc has turned a certain amount, fails when
# applied to an arc whose direction of curvature changes in the middle.
# (See class Curve2BezierOptions in the code.)

c2bo = Curve2BezierOptions(
    cusp_points           = False, # Unnecessary to search for cusps.
    high_curvature_points = True,  # Finds the extrema.
    low_curvature_points  = False, # To stop searching for inflection points.
    straight_end_points   = False, # Unnecessary.
    inflection_points     = False, # Again, we do not want the inflection points.
    angle_turn_points     = False  # Must now be False: see above.
    )

c2bs = Curve2BezierSettings(
    #max_error = 0.0001 # Uncommenting this brings up inflection points after all
    )

coos = CoordinateSettings(
    fit_window = True,
    )

drawo = DrawingOptions(
    bezier_curves  = True,
    bezier_collage = False,
    axes           = False,
    x_axis         = True,
    exact_pcurves  = True, # To check the result
    handles        = True, # To see handles: may be interesting
    )

