# Draw some spring-like figures.
# Note: We set custom points to where we would like to have anchors.
# Simultaneously we suppress searching for high_curvature_points,
# low_curvature_points, and angle_turn_points; otherwise there would
# be too many anchors.
# This is slow!

q = 3
v = .3
n = 20
f = 1./10

def spring0(t):
    x,y = cos(t), q*sin(t)
    x_loc = v*t
    y_loc = 0
    return [x_loc + x, y_loc + y]

def spring1(t):
    x,y = cos(t), q*sin(t)
    x_loc = v*t
    y_loc = 2*q+1
    longitudinal = 1.5*cos(f*t)
    return [x_loc + longitudinal + x, y_loc + y]

def spring2(t):
    x,y = cos(t), q*sin(t)
    x_loc = v*t
    y_loc = 4*q+3
    transverse = q*sin(f*t)/2
    return [x_loc + x, y_loc + transverse + y]

def spring3(t):
    x,y = cos(t), q*sin(t)
    x_loc = v*t
    y_loc = 6*q+4
    transverse = q*sin(f*t)/2
    # Rotation:
    a,b = v, q*f*cos(f*t)/2 # D(x_loc), D(transverse)
    c = sqrt(a**2+b**2)
    a,b = a/c, b/c
    x,y = a*x - b*y, b*x + a*y
    return [x_loc + x, y_loc + transverse + y]

def spring4(t):
    x,y = cos(t), q*sin(t)
    x_loc = v*t
    y_loc = 8*q+6
    transverse = q*sin(f*t)/2
    longitudinal = 0.3*cos(2*f*t - pi/2)
    # Rotation:
    a,b = v, q*f*cos(f*t)/2 # D(x_loc), D(transverse)
    c = sqrt(a**2+b**2)
    a,b = a/c, b/c
    x,y = a*x - b*y, b*x + a*y
    return [x_loc + longitudinal + x, y_loc + transverse + y]

def wave4(t):
    x_loc = v*t
    y_loc = 8*q+6
    transverse = q*sin(f*t)/2
    return [x_loc, y_loc + transverse]

custom_params = ([pi/2+k*pi for k in range(-1,2*n)]
                 +[k*pi for k in range(2*n)])

pcurve0 = ParametricCurve(
    function = spring0,
    pcurve_name = "spring 0",
    start  = -pi,
    end    = n*2*pi,
    closed = False,
    custom = CustomPoints(params=custom_params)
    )

pcurve1 = ParametricCurve(
    function = spring1,
    pcurve_name = "spring 1",
    start  = -pi,
    end    = n*2*pi,
    closed = False,
    custom = CustomPoints(params=custom_params)
    )

pcurve2 = ParametricCurve(
    function = spring2,
    pcurve_name = "spring 2",
    start  = -pi,
    end    = n*2*pi,
    closed = False,
    custom = CustomPoints(params=custom_params)
    )

pcurve3 = ParametricCurve(
    function = spring3,
    pcurve_name = "spring 3",
    start  = -pi,
    end    = n*2*pi,
    closed = False,
    custom = CustomPoints(params=custom_params)
    )

pcurve4 = ParametricCurve(
    function = spring4,
    pcurve_name = "spring 4",
    start  = -pi,
    end    = n*2*pi,
    closed = False,
    custom = CustomPoints(params=custom_params)
    )

pcurve_wave4 = ParametricCurve(
    function = wave4,
    pcurve_name = "wave 4",
    start  = -pi,
    end    = n*2*pi,
    closed = False,
    custom = CustomPoints(params=custom_params)
    )

pcurve_collage = ParametricCurveCollage(
    pcurve_list  = [pcurve0,pcurve1,pcurve2,pcurve3,pcurve4, pcurve_wave4],
    collage_name = 'Springs'
    )

c2bo = Curve2BezierOptions(      # Opposite to default values
    high_curvature_points = False,
    low_curvature_points  = False,
    angle_turn_points     = False
    )

drawo = DrawingOptions()
