# This file lists all possible ingredients in an input file.
# They are shown here in the form of an example but without any explanations.
# This file is itself valid as an input  inputs, and you can edit the fields.
# For explanations of the inputs, see the file doc.pdf.
#
# Note: Taking the benefit of default values, the inputs can be written
# much more tersely. For such usage, see other example files -- in this file
# all possible input fields are written in full.


def cardioid(t):
    from math import sin,cos
    return [2*cos(t)-cos(2*t), 2*sin(t)-sin(2*t)]

def astroid(t):
    from math import sin,cos
    return [cos(t)**3, sin(t)**3]

def astroid2(t):
    from math import sin,cos
    return [-2 + cos(t)**3, sin(t)**3]

pcurve0 = ParametricCurve(                # Cardioid
    function = cardioid,
    pcurve_name   = "cardioid",
    start  = 0.,
    end    = 2*pi,
    closed = True,
    custom = CustomPoints( # These custom points serve only as as examples.
        params = [19*pi/24, 11*pi/12],
        points = [[-2.5, -2], [-2, -2]],
        screen_points = [[800,920], [520,940]]
        )
    )

pcurve1 = ParametricCurve(                # Astroid
    function    = astroid,
    pcurve_name = "astroid",
    start  = 0.,
    end    = 2*pi,
    closed = True,
    custom = CustomPoints(params = [pi/2, pi, 3*pi/2])
    )

pcurve2 = ParametricCurve(                # Astroid
    function    = astroid2,
    pcurve_name = "astroid2",
    start  = 0.,
    end    = 2*pi,
    closed = True,
    custom = CustomPoints(params = [pi/2, pi, 3*pi/2])
    )

pcurve_collage = ParametricCurveCollage(
    pcurve_list  = [pcurve0, pcurve1, pcurve2],
    collage_name = 'Example: One cardioid and two astroids'
    )

c2bs = Curve2BezierSettings(    # These are default values.
    angle         = math.pi/2,
    refinement    = 0,
    max_error     = 0.02,
    max_recursion = 3,
    )

c2bo = Curve2BezierOptions(     # These are default values.
    cusp_points           = True,
    high_curvature_points = True,
    low_curvature_points  = True,
    straight_end_points   = True,
    inflection_points     = False,
    angle_turn_points     = True
    )

coos = CoordinateSettings(      # These are default values.
    fit_window   = True,
    padding      = .0,
    origo        = [600.,450.],
    scale        = 450.
    )

drawo = DrawingOptions(
    bezier_curves  = False,
    bezier_collage = True,
    axes           = False,
    x_axis         = False,
    y_axis         = False,
    exact_pcurves  = False,
    handles        = False,
    )

mark_polylines = [
                   [[-4,0],[2,0]],        # x axis
                   [[0,-3],[0,3], False], # y axis (False is default)
                   [[-2,0]],              # center of the left astroid
                   # lines around the right astroid:
                   [astroid(0),astroid(pi/2),astroid(pi),astroid(3*pi/2), True]
                  ]
