# Draw a nice figure from two cardioids: an example where we build
# a 'pcurve_collage' consisting of two parametric curves.

def cardioid_1(t):
    return [-1 + (2*cos(t)-cos(2*t)), 2*sin(t)-sin(2*t)]

def cardioid_2(t):
    return [ 1 - (2*cos(t)-cos(2*t)), 2*sin(t)-sin(2*t)]

pcurve1 = ParametricCurve(                # Cardioid
    function = cardioid_1,
    pcurve_name = "cardioid 1",
    start  = 0.,
    end    = 2*pi,
    closed = True,
    )

pcurve2 = ParametricCurve(                # Cardioid
    function = cardioid_2,
    pcurve_name = "cardioid 2",
    start  = 0.,
    end    = 2*pi,
    closed = True,
    )

pcurve_collage = ParametricCurveCollage(
    pcurve_list  = [pcurve1, pcurve2],
    collage_name = None
    )

c2bs = Curve2BezierSettings() # default

c2bo = Curve2BezierOptions()  # default

coos = CoordinateSettings()   # default

drawo = DrawingOptions(
    bezier_curves  = True, # Draw the two cardioids both individually,
    bezier_collage = True, # and together.
    handles = True         # Draw the anchors and handles just for fun.
    )

